@@ -10,8 +10,8 @@ else:
 
 from datetime import datetime
 
-__version__ = '0.7.0'
-URL = 'https://d3design.tools'
+__version__ = '0.7.2'
+URL = 'https://d3design.tools/d3cloud'
 
 
 class Client(object):
@@ -185,7 +185,7 @@ class Client(object):
         with open(simulationGeometries, 'rb') as f:
             r = requests.post(
                 URL+'/upload',
-                files = {'file1': f},
+                files = {'uploadedFile': f},
                 data = {
                     'simulationType':simulationType,
                     'api':'true',
@@ -358,7 +358,7 @@ class Client(object):
             cases (list[float], optional): List of cases ID to download ply files for. Set to None for downloading all available cases. Defaults to None.
         """
         self.__downloadResults(projectName,simulationName,'ply',localPath,cases)
-    
+
     def downloadEnsight(self,projectName,simulationName,localPath,cases=None):
         """Download ensight file of a simulation.
 
